.. currentmodule:: pyasge

Camera
=====================
.. autoclass:: Camera
   :members:

CameraView
=====================
.. autoclass:: CameraView
.. rubric:: Attributes
.. autosummary::
      ~CameraView.min_x
      ~CameraView.max_x
      ~CameraView.min_y
      ~CameraView.max_y

Colour
=====================
.. autoclass:: Colour
   :members:

CursorMode
=====================
.. autoclass:: CursorMode
   :members:

EventType
=====================
.. autoclass:: EventType
   :members:

Font
=====================
.. autoclass:: Font
   :members:

Game
=====================
.. autoclass:: ASGEGame
   :show-inheritance:
   :members:
   :inherited-members:

GameSettings
=====================
.. autoclass:: GameSettings
   :members:

GamePad
=====================
.. autoclass:: GamePad
   :members:

GameTime
=====================
.. autoclass:: GameTime
   :members:

Input
=====================
.. autoclass:: Input
   :members:

InputEvents
=====================
.. autoclass:: ClickEvent
   :members:
.. autoclass:: KeyEvent
   :members:
.. autoclass:: MoveEvent
   :members:
.. autoclass:: ScrollEvent
   :members:

Magfilter
=====================
.. autoclass:: MagFilter
   :members:

Point2D
=====================
.. autoclass:: Point2D
   :members:

PixelBuffer
=====================
.. autoclass:: PixelBuffer
   :members:

Renderer
=====================
.. autoclass:: Renderer
   :members:

RenderTarget
=====================
.. autoclass:: RenderTarget
   :members:

Shader
=====================
.. autoclass:: Shader
   :members:
.. autosummary::
   :toctree: _generate

Sprite
=====================
.. autoclass:: Sprite
   :members:
.. autosummary::
   :toctree: _generate

SpriteBounds
=====================
.. autoclass:: SpriteBounds
.. rubric:: Attributes
.. autosummary::
      ~SpriteBounds.v1
      ~SpriteBounds.v2
      ~SpriteBounds.v3
      ~SpriteBounds.v4

Text
=====================
.. autoclass:: Text
   :members:

Texture
=====================
.. autoclass:: Texture
   :members:

Value
=====================
.. autoclass:: Value
   :members:

Viewport
=====================
.. autoclass:: Viewport
   :members:

Vsync
=====================
.. autoclass:: Vsync
   :members:

WindowMode
=====================
.. autoclass:: WindowMode
   :members:
